Structural Similarity (SSIM)
============================

.. automodule:: viqa.fr_metrics.ssim
    :exclude-members: SSIM, structural_similarity

   
.. rubric:: Functions

.. currentmodule:: viqa.fr_metrics.ssim

.. autosummary::
    :toctree: generated/

    structural_similarity


.. rubric:: Classes

.. currentmodule:: viqa.fr_metrics.ssim

.. autosummary::
    :toctree: generated/
    :template: class.rst

    SSIM